@@ -124,7 +124,8 @@ def naturaldelta(
     """
     tmp = Unit[minimum_unit.upper()]
     if tmp not in (Unit.SECONDS, Unit.MILLISECONDS, Unit.MICROSECONDS):
-        raise ValueError(f"Minimum unit '{minimum_unit}' not supported")
+        msg = f"Minimum unit '{minimum_unit}' not supported"
+        raise ValueError(msg)
     min_unit = tmp
 
     if isinstance(value, dt.timedelta):
@@ -151,7 +152,8 @@ def naturaldelta(
                     _ngettext("%d microsecond", "%d microseconds", delta.microseconds)
                     % delta.microseconds
                 )
-            elif min_unit == Unit.MILLISECONDS or (
+
+            if min_unit == Unit.MILLISECONDS or (
                 min_unit == Unit.MICROSECONDS and 1000 <= delta.microseconds < 1_000_000
             ):
                 milliseconds = delta.microseconds / 1000
@@ -160,47 +162,59 @@ def naturaldelta(
                     % milliseconds
                 )
             return _("a moment")
-        elif seconds == 1:
+
+        if seconds == 1:
             return _("a second")
-        elif seconds < 60:
+
+        if seconds < 60:
             return _ngettext("%d second", "%d seconds", seconds) % seconds
-        elif 60 <= seconds < 120:
+
+        if 60 <= seconds < 120:
             return _("a minute")
-        elif 120 <= seconds < 3600:
+
+        if 120 <= seconds < 3600:
             minutes = seconds // 60
             return _ngettext("%d minute", "%d minutes", minutes) % minutes
-        elif 3600 <= seconds < 3600 * 2:
+
+        if 3600 <= seconds < 3600 * 2:
             return _("an hour")
-        elif 3600 < seconds:
+
+        if 3600 < seconds:
             hours = seconds // 3600
             return _ngettext("%d hour", "%d hours", hours) % hours
+
     elif years == 0:
         if days == 1:
             return _("a day")
+
         if not use_months:
             return _ngettext("%d day", "%d days", days) % days
-        else:
-            if not num_months:
-                return _ngettext("%d day", "%d days", days) % days
-            elif num_months == 1:
-                return _("a month")
-            else:
-                return _ngettext("%d month", "%d months", num_months) % num_months
+
+        if not num_months:
+            return _ngettext("%d day", "%d days", days) % days
+
+        if num_months == 1:
+            return _("a month")
+
+        return _ngettext("%d month", "%d months", num_months) % num_months
+
     elif years == 1:
         if not num_months and not days:
             return _("a year")
-        elif not num_months:
+
+        if not num_months:
             return _ngettext("1 year, %d day", "1 year, %d days", days) % days
-        elif use_months:
+
+        if use_months:
             if num_months == 1:
                 return _("1 year, 1 month")
-            else:
-                return (
-                    _ngettext("1 year, %d month", "1 year, %d months", num_months)
-                    % num_months
-                )
-        else:
-            return _ngettext("1 year, %d day", "1 year, %d days", days) % days
+
+            return (
+                _ngettext("1 year, %d month", "1 year, %d months", num_months)
+                % num_months
+            )
+
+        return _ngettext("1 year, %d day", "1 year, %d days", days) % days
 
     return _ngettext("%d year", "%d years", years).replace("%d", "%s") % intcomma(years)
 
@@ -265,12 +279,16 @@ def naturalday(value: dt.date | dt.datetime, format: str = "%b %d") -> str:
         # Date arguments out of range
         return str(value)
     delta = value - dt.date.today()
+
     if delta.days == 0:
         return _("today")
-    elif delta.days == 1:
+
+    if delta.days == 1:
         return _("tomorrow")
-    elif delta.days == -1:
+
+    if delta.days == -1:
         return _("yesterday")
+
     return value.strftime(format)
 
 
@@ -323,10 +341,11 @@ def _quotient_and_remainder(
     """
     if unit == minimum_unit:
         return value / divisor, 0
-    elif unit in suppress:
+
+    if unit in suppress:
         return 0, value
-    else:
-        return divmod(value, divisor)
+
+    return divmod(value, divisor)
 
 
 def _carry(
@@ -361,10 +380,11 @@ def _carry(
     """
     if unit == min_unit:
         return value1 + value2 / ratio, 0
-    elif unit in suppress:
+
+    if unit in suppress:
         return 0, value2 + value1 * ratio
-    else:
-        return value1, value2
+
+    return value1, value2
 
 
 def _suitable_minimum_unit(min_unit: Unit, suppress: typing.Iterable[Unit]) -> Unit:
@@ -376,7 +396,7 @@ def _suitable_minimum_unit(min_unit: Unit, suppress: typing.Iterable[Unit]) -> U
     >>> _suitable_minimum_unit(Unit.HOURS, []).name
     'HOURS'
 
-    But if suppressed, find a unit greather than the original one that is not
+    But if suppressed, find a unit greater than the original one that is not
     suppressed:
 
     >>> _suitable_minimum_unit(Unit.HOURS, [Unit.HOURS]).name
@@ -390,9 +410,8 @@ def _suitable_minimum_unit(min_unit: Unit, suppress: typing.Iterable[Unit]) -> U
             if unit > min_unit and unit not in suppress:
                 return unit
 
-        raise ValueError(
-            "Minimum unit is suppressed and no suitable replacement was found"
-        )
+        msg = "Minimum unit is suppressed and no suitable replacement was found"
+        raise ValueError(msg)
 
     return min_unit
 
@@ -405,16 +424,16 @@ def _suppress_lower_units(min_unit: Unit, suppress: typing.Iterable[Unit]) -> se
     ['MICROSECONDS', 'MILLISECONDS', 'DAYS']
     """
     suppress = set(suppress)
-    for u in Unit:
-        if u == min_unit:
+    for unit in Unit:
+        if unit == min_unit:
             break
-        suppress.add(u)
+        suppress.add(unit)
 
     return suppress
 
 
 def precisedelta(
-    value: dt.timedelta | int,
+    value: dt.timedelta | int | None,
     minimum_unit: str = "seconds",
     suppress: typing.Iterable[str] = (),
     format: str = "%0.2f",
