@@ -1,6 +1,7 @@
 """Number tests."""
 from __future__ import annotations
 
+import math
 import typing
 
 import pytest
@@ -25,6 +26,11 @@ from humanize import number
         ("111", "111th"),
         ("something else", "something else"),
         (None, "None"),
+        (math.nan, "NaN"),
+        (math.inf, "+Inf"),
+        (-math.inf, "-Inf"),
+        ("nan", "NaN"),
+        ("-inf", "-Inf"),
     ],
 )
 def test_ordinal(test_input: str, expected: str) -> None:
@@ -46,6 +52,10 @@ def test_ordinal(test_input: str, expected: str) -> None:
         (["10311"], "10,311"),
         (["1000000"], "1,000,000"),
         (["1234567.1234567"], "1,234,567.1234567"),
+        (["1234567.1234567", 0], "1,234,567"),
+        (["1234567.1234567", 1], "1,234,567.1"),
+        (["1234567.1234567", 10], "1,234,567.1234567000"),
+        (["1234567", 1], "1,234,567.0"),
         ([None], "None"),
         ([14308.40], "14,308.4"),
         ([14308.40, None], "14,308.4"),
@@ -59,6 +69,11 @@ def test_ordinal(test_input: str, expected: str) -> None:
         ([1234.5454545, 2], "1,234.55"),
         ([1234.5454545, 3], "1,234.545"),
         ([1234.5454545, 10], "1,234.5454545000"),
+        ([math.nan], "NaN"),
+        ([math.inf], "+Inf"),
+        ([-math.inf], "-Inf"),
+        (["nan"], "NaN"),
+        (["-inf"], "-Inf"),
     ],
 )
 def test_intcomma(
@@ -75,27 +90,42 @@ def test_intword_powers() -> None:
 @pytest.mark.parametrize(
     "test_args, expected",
     [
+        (["0"], "0"),
         (["100"], "100"),
+        (["-100"], "-100"),
         (["1000"], "1.0 thousand"),
         (["12400"], "12.4 thousand"),
         (["12490"], "12.5 thousand"),
         (["1000000"], "1.0 million"),
+        (["-1000000"], "-1.0 million"),
         (["1200000"], "1.2 million"),
         (["1290000"], "1.3 million"),
         (["999999999"], "1.0 billion"),
         (["1000000000"], "1.0 billion"),
+        (["-1000000000"], "-1.0 billion"),
         (["2000000000"], "2.0 billion"),
         (["999999999999"], "1.0 trillion"),
         (["1000000000000"], "1.0 trillion"),
         (["6000000000000"], "6.0 trillion"),
+        (["-6000000000000"], "-6.0 trillion"),
         (["999999999999999"], "1.0 quadrillion"),
         (["1000000000000000"], "1.0 quadrillion"),
         (["1300000000000000"], "1.3 quadrillion"),
+        (["-1300000000000000"], "-1.3 quadrillion"),
         (["3500000000000000000000"], "3.5 sextillion"),
         (["8100000000000000000000000000000000"], "8.1 decillion"),
+        (["-8100000000000000000000000000000000"], "-8.1 decillion"),
+        ([1_000_000_000_000_000_000_000_000_000_000_000_000], "1000.0 decillion"),
+        ([1_100_000_000_000_000_000_000_000_000_000_000_000], "1100.0 decillion"),
+        ([2_100_000_000_000_000_000_000_000_000_000_000_000], "2100.0 decillion"),
         ([None], "None"),
         (["1230000", "%0.2f"], "1.23 million"),
         ([10**101], "1" + "0" * 101),
+        ([math.nan], "NaN"),
+        ([math.inf], "+Inf"),
+        ([-math.inf], "-Inf"),
+        (["nan"], "NaN"),
+        (["-inf"], "-Inf"),
     ],
 )
 def test_intword(test_args: list[str], expected: str) -> None:
@@ -114,6 +144,11 @@ def test_intword(test_args: list[str], expected: str) -> None:
         (10, "10"),
         ("7", "seven"),
         (None, "None"),
+        (math.nan, "NaN"),
+        (math.inf, "+Inf"),
+        (-math.inf, "-Inf"),
+        ("nan", "NaN"),
+        ("-inf", "-Inf"),
     ],
 )
 def test_apnumber(test_input: int | str, expected: str) -> None:
@@ -135,6 +170,11 @@ def test_apnumber(test_input: int | str, expected: str) -> None:
         (1.5, "1 1/2"),
         (0.3, "3/10"),
         (0.333, "333/1000"),
+        (math.nan, "NaN"),
+        (math.inf, "+Inf"),
+        (-math.inf, "-Inf"),
+        ("nan", "NaN"),
+        ("-inf", "-Inf"),
     ],
 )
 def test_fractional(test_input: float | str, expected: str) -> None:
@@ -161,6 +201,11 @@ def test_fractional(test_input: float | str, expected: str) -> None:
         ([float(2e-20)], "2.00 x 10⁻²⁰"),
         ([float(-3e20)], "-3.00 x 10²⁰"),
         ([float(-4e-20)], "-4.00 x 10⁻²⁰"),
+        ([math.nan], "NaN"),
+        ([math.inf], "+Inf"),
+        ([-math.inf], "-Inf"),
+        (["nan"], "NaN"),
+        (["-inf"], "-Inf"),
     ],
 )
 def test_scientific(test_args: list[typing.Any], expected: str) -> None:
@@ -178,6 +223,9 @@ def test_scientific(test_args: list[typing.Any], expected: str) -> None:
         ([0.0001, "{:.0%}", 0.01, None, "under ", None], "under 1%"),
         ([0.9999, "{:.0%}", None, 0.99, None, "above "], "above 99%"),
         ([1, humanize.intword, 1e6, None, "under "], "under 1.0 million"),
+        ([math.nan], "NaN"),
+        ([math.inf], "+Inf"),
+        ([-math.inf], "-Inf"),
     ],
 )
 def test_clamp(test_args: list[typing.Any], expected: str) -> None:
@@ -187,6 +235,7 @@ def test_clamp(test_args: list[typing.Any], expected: str) -> None:
 @pytest.mark.parametrize(
     "test_args, expected",
     [
+        ([0], "0.00"),
         ([1, "Hz"], "1.00 Hz"),
         ([1.0, "W"], "1.00 W"),
         ([3, "C"], "3.00 C"),
@@ -199,8 +248,14 @@ def test_clamp(test_args: list[typing.Any], expected: str) -> None:
         ([200_000], "200 k"),
         ([1e25, "m"], "10.0 Ym"),
         ([1e26, "m"], "100 Ym"),
-        ([1e27, "A"], "1.00 x 10²⁷A"),
-        ([1.234e28, "A"], "1.23 x 10²⁸A"),
+        ([1e27, "A"], "1.00 RA"),
+        ([1.234e28, "A"], "12.3 RA"),
+        ([1.234e-28, "A"], "123 qA"),
+        ([1.235e29, "A"], "124 RA"),
+        ([2.56e-30, "V"], "2.56 qV"),
+        ([2.596e32, "F"], "260 QF"),
+        ([1e50], "1.00 x 10⁵⁰"),
+        ([1e-50], "1.00 x 10⁻⁵⁰"),
         ([-1500, "V"], "-1.50 kV"),
         ([0.12], "120 m"),
         ([0.012], "12.0 m"),
@@ -208,12 +263,16 @@ def test_clamp(test_args: list[typing.Any], expected: str) -> None:
         ([0.00012], "120 μ"),
         ([1e-23], "10.0 y"),
         ([1e-24], "1.00 y"),
-        ([1e-25], "1.00 x 10⁻²⁵"),
-        ([1e-26], "1.00 x 10⁻²⁶"),
+        ([1e-25], "100 r"),
+        ([1e-26], "10.0 r"),
         ([1, "°"], "1.00°"),
         ([0.1, "°"], "100m°"),
         ([100], "100"),
         ([0.1], "100 m"),
+        ([math.nan], "NaN"),
+        ([math.nan, "m"], "NaN"),
+        ([math.inf], "+Inf"),
+        ([-math.inf], "-Inf"),
     ],
     ids=str,
 )
